@@ -71,6 +71,7 @@ allowAnonymousChangePassword = {{allow_anonymous_change_password}}
 allowProjectResourceMonitor = {{allow_project_resource_monitor}}
 allowManualImageNameForSession = {{allow_manual_image_name_for_session}}
 autoLogout = {{auto_logout}}
+debug = {{webui_debug}}
 
 [resources]
 openPortToPublic = {{open_port_to_public}}
@@ -81,8 +82,15 @@ maxCUDASharesPerContainer = {{max_cuda_shares_per_container}}
 maxShmPerContainer = {{max_shm_per_container}}
 maxFileUploadSize = {{max_file_upload_size}}
 
+[environments]
+{% if environment_allowlist %}
+allowlist = "{{environment_allowlist}}"
+{% endif %}
+
 [menu]
+{% if menu_blocklist %}
 blocklist = "{{menu_blocklist}}"
+{% endif %}
 
 {% if console_menu_plugins %}
 [plugin]
@@ -184,6 +192,7 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
                 'true' if config['service']['allow_project_resource_monitor'] else 'false',
             'allow_manual_image_name_for_session':
                 'true' if config['service'].get('allow_manual_image_name_for_session') else 'false',
+            'webui_debug': 'true' if config['service'].get('webui_debug') else 'false',
             'auto_logout':
                 'true' if config['session'].get('auto_logout') else 'false',
             'open_port_to_public': open_port_to_public,
@@ -193,6 +202,7 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
             'max_cuda_shares_per_container': max_cuda_shares_per_container,
             'max_shm_per_container': max_shm_per_container,
             'max_file_upload_size': max_file_upload_size,
+            'environment_allowlist': config['environments'].get('allowlist', ''),
             'menu_blocklist': config['ui'].get('menu_blocklist', ''),
             'console_menu_plugins': console_menu_plugins,
             'license_edition': license_edition,
@@ -438,6 +448,9 @@ async def token_login_handler(request: web.Request) -> web.Response:
         )
         assert anon_api_config.is_anonymous
         async with APISession(config=anon_api_config) as api_session:
+            # Send X-Forwarded-For header for token authentication with the client IP.
+            _headers = {'X-Forwarded-For': request.headers.get('X-Forwarded-For', '')}
+            api_session.aiohttp_session.headers.update(_headers)
             # Instead of email and password, cookie token will be used for auth.
             api_session.aiohttp_session.cookie_jar.update_cookies(request.cookies)
             token = await api_session.User.authorize('fake-email', 'fake-pwd')
